==> kdeedu-3.0.1.tar.bz2: kdeedu-3.0.1/kmessedwords/kmessedwords/splashscreen.h <==
/***************************************************************************
                          splashscreen.h  -  description
                             -------------------
    begin                : Thu Nov 1 2001
    copyright            : (C) 2001 by Primoz Anzur (zer0Kode)
    email                : zerokode@yahoo.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SPLASHSCREEN_H
#define SPLASHSCREEN_H
//#define LOCAL_VERSION "1.0.1"

#include <splash.h>
#include <qpixmap.h>
#include <kstandarddirs.h>
#include <qevent.h>
#include <qtimer.h>

#include "mainwindow.h"

/**
  *@author Primoz Anzur (zer0Kode)
  */

class SplashScreen : public KMWSplash  {
public: 
	SplashScreen();
	~SplashScreen();
	MainWindow loadMain;	
public slots:
	virtual void showMainWindow();

protected:
   void closeEvent(QCloseEvent *);
};

#endif

==> kdeedu-3.1.4.tar.bz2: kdeedu-3.1.4/kmessedwords/kmessedwords/splashscreen.h <==
/***************************************************************************
                          splashscreen.h  -  description
                             -------------------
    begin                : Thu Nov 1 2001
    copyright            : (C) 2001 by Primoz Anzur (zer0Kode)
    email                : zerokode@yahoo.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SPLASHSCREEN_H
#define SPLASHSCREEN_H

//KDE stuff
#include <kstandarddirs.h>

//Qt stuff...
#include <qpixmap.h>
#include <qevent.h>
#include <qtimer.h>
#include <qframe.h>
#include <qwidget.h>

#include "mainwindow.h"

/**
  *@author Whitehawk Stormchaser
  */

class SplashScreen : public QFrame  
{
Q_OBJECT
public: 
	SplashScreen(QWidget *parent=0, const char *name=0);
	~SplashScreen();
	MainWindow loadMain;
public slots:
	void showMainWindow();

protected:
   void closeEvent(QCloseEvent *);
};

#endif
